@@ -60,6 +60,7 @@ var (
 	schedulingGroup            = "scheduling.k8s.io"
 	kAuthzGroup                = kauthorizationapi.GroupName
 	kAuthnGroup                = kauthenticationapi.GroupName
+	discoveryGroup             = "discovery.k8s.io"
 
 	deployGroup         = oapps.GroupName
 	authzGroup          = authorization.GroupName
@@ -290,9 +291,24 @@ func GetOpenshiftBootstrapClusterRoles() []rbacv1.ClusterRole {
 			},
 		},
 		{
+			// Aggregated: cluster-csi-snapshot-controller-operator needs to grant storage-admin permissions to manage
+			// VolumeSnapshotContents (=~PV) and VolumeSnapshotClasses (=~StorageClass).
 			ObjectMeta: metav1.ObjectMeta{
 				Name: StorageAdminRoleName,
 			},
+			AggregationRule: &rbacv1.AggregationRule{
+				ClusterRoleSelectors: []metav1.LabelSelector{
+					{
+						MatchLabels: map[string]string{"storage.openshift.io/aggregate-to-storage-admin": "true"},
+					},
+				},
+			},
+		},
+		{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:   AggregatedStorageAdminRoleName,
+				Labels: map[string]string{"storage.openshift.io/aggregate-to-storage-admin": "true"},
+			},
 			Rules: []rbacv1.PolicyRule{
 				rbacv1helpers.NewRule(readWrite...).Groups(kapiGroup).Resources("persistentvolumes").RuleOrDie(),
 				rbacv1helpers.NewRule(readWrite...).Groups(storageGroup).Resources("storageclasses").RuleOrDie(),
@@ -423,12 +439,27 @@ func GetOpenshiftBootstrapClusterRoles() []rbacv1.ClusterRole {
 			},
 		},
 		{
+			// Aggregated: cluster-csi-snapshot-controller-operator needs to grant basic-user permissions to read
+			// non-namespaced VolumeSnapshotClasses.
 			ObjectMeta: metav1.ObjectMeta{
 				Name: BasicUserRoleName,
 				Annotations: map[string]string{
 					openShiftDescription: "A user that can get basic information about projects.",
 				},
 			},
+			AggregationRule: &rbacv1.AggregationRule{
+				ClusterRoleSelectors: []metav1.LabelSelector{
+					{
+						MatchLabels: map[string]string{"authorization.openshift.io/aggregate-to-basic-user": "true"},
+					},
+				},
+			},
+		},
+		{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:   AggregatedBasicUserRoleName,
+				Labels: map[string]string{"authorization.openshift.io/aggregate-to-basic-user": "true"},
+			},
 			Rules: []rbacv1.PolicyRule{
 				rbacv1helpers.NewRule("get").Groups(userGroup, legacyUserGroup).Resources("users").Names("~").RuleOrDie(),
 				rbacv1helpers.NewRule("list").Groups(projectGroup, legacyProjectGroup).Resources("projectrequests").RuleOrDie(),
@@ -597,6 +628,7 @@ func GetOpenshiftBootstrapClusterRoles() []rbacv1.ClusterRole {
 				Name: RouterRoleName,
 			},
 			Rules: []rbacv1.PolicyRule{
+				rbacv1helpers.NewRule("list", "watch").Groups(discoveryGroup).Resources("endpointslices").RuleOrDie(),
 				rbacv1helpers.NewRule("list", "watch").Groups(kapiGroup).Resources("endpoints").RuleOrDie(),
 				rbacv1helpers.NewRule("list", "watch").Groups(kapiGroup).Resources("services").RuleOrDie(),
 
@@ -607,19 +639,6 @@ func GetOpenshiftBootstrapClusterRoles() []rbacv1.ClusterRole {
 				rbacv1helpers.NewRule("update").Groups(routeGroup, legacyRouteGroup).Resources("routes/status").RuleOrDie(),
 			},
 		},
-		{
-			ObjectMeta: metav1.ObjectMeta{
-				Name: RegistryRoleName,
-			},
-			Rules: []rbacv1.PolicyRule{
-				rbacv1helpers.NewRule("list").Groups(kapiGroup).Resources("limitranges", "resourcequotas", "imagestreams").RuleOrDie(),
-
-				rbacv1helpers.NewRule("get", "delete").Groups(imageGroup, legacyImageGroup).Resources("images", "imagestreamtags", "imagetags").RuleOrDie(),
-				rbacv1helpers.NewRule("get").Groups(imageGroup, legacyImageGroup).Resources("imagestreamimages", "imagestreams/secrets").RuleOrDie(),
-				rbacv1helpers.NewRule("get", "update").Groups(imageGroup, legacyImageGroup).Resources("images", "imagestreams").RuleOrDie(),
-				rbacv1helpers.NewRule("create").Groups(imageGroup, legacyImageGroup).Resources("imagestreammappings").RuleOrDie(),
-			},
-		},
 		{
 			ObjectMeta: metav1.ObjectMeta{
 				Name: NodeAdminRoleName,
@@ -875,5 +894,7 @@ func addDefaultMetadata(obj runtime.Object) {
 func GetBootstrapClusterRolesToAggregate() map[string]string {
 	return map[string]string{
 		ClusterReaderRoleName: AggregatedClusterReaderRoleName,
+		BasicUserRoleName:     AggregatedBasicUserRoleName,
+		StorageAdminRoleName:  AggregatedStorageAdminRoleName,
 	}
 }
