@@ -6,8 +6,11 @@ import (
 
 	"github.com/openshift/api/image/docker10"
 	"github.com/openshift/api/image/dockerpre012"
-	"github.com/openshift/api/image/v1"
+	v1 "github.com/openshift/api/image/v1"
+
 	"github.com/openshift/openshift-apiserver/pkg/image/apis/image"
+	imagedocker10helpers "github.com/openshift/openshift-apiserver/pkg/image/apis/image/docker10"
+	imagedockerpre012helpers "github.com/openshift/openshift-apiserver/pkg/image/apis/image/dockerpre012"
 )
 
 var (
@@ -15,8 +18,10 @@ var (
 		image.Install,
 		v1.Install,
 		corev1conversions.AddToScheme,
-		docker10.AddToScheme,
-		dockerpre012.AddToScheme,
+		imagedocker10helpers.Install,
+		imagedockerpre012helpers.Install,
+		docker10.AddToSchemeInCoreGroup,
+		dockerpre012.AddToSchemeInCoreGroup,
 
 		addFieldSelectorKeyConversions,
 		AddConversionFuncs,
