@@ -1,12 +1,11 @@
 package imagestreamtag
 
 import (
+	"context"
 	"reflect"
 	"testing"
 	"time"
 
-	"golang.org/x/net/context"
-
 	etcd "go.etcd.io/etcd/clientv3"
 	authorizationapi "k8s.io/api/authorization/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
